@@ -1,44 +1,41 @@
 #!/usr/bin/env python3
 
-"""
-Copyright (c) 2008-2024, Jesús Cea Avión <jcea@jcea.es>
-All rights reserved.
-
-Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions
-are met:
-
-1. Redistributions of source code must retain the above copyright
-notice, this list of conditions and the following disclaimer.
-
-2. Redistributions in binary form must reproduce the above
-copyright notice, this list of conditions and the following
-disclaimer in the documentation and/or other materials provided
-with the distribution.
-
-3. Neither the name of Jesús Cea Avión nor the names of its
-contributors may be used to endorse or promote products derived
-from this software without specific prior written permission.
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
-CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
-INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
-MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
-BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
-TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
-ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
-TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
-THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGE.
-"""
+# Copyright (c) 2008-2024, Jesús Cea Avión <jcea@jcea.es>
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+#
+# 1. Redistributions of source code must retain the above copyright
+# notice, this list of conditions and the following disclaimer.
+#
+# 2. Redistributions in binary form must reproduce the above
+# copyright notice, this list of conditions and the following
+# disclaimer in the documentation and/or other materials provided
+# with the distribution.
+#
+# 3. Neither the name of Jesús Cea Avión nor the names of its
+# contributors may be used to endorse or promote products derived
+# from this software without specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
+# CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
+# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
+# BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+# ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
+# TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
+# THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+# SUCH DAMAGE.
 
 import os
 import re
 import sys
-import glob
 
 
 # See https://setuptools.readthedocs.io/en/latest/deprecated/\
@@ -155,7 +152,8 @@ if os.name == 'posix':
 
         db_ver_inc_map = {}
 
-        class db_found(Exception): pass
+        class db_found(Exception):
+            pass
         try:
             # this CCompiler object is only used to locate include files
             compiler = distutils.ccompiler.new_compiler()
@@ -173,7 +171,8 @@ if os.name == 'posix':
             # search path.
             for d in inc_dirs + db_inc_paths:
                 f = os.path.join(d, "db.h")
-                if debug: print("db: looking for db.h in", f)
+                if debug:
+                    print("db: looking for db.h in", f)
                 if os.path.exists(f):
                     with open(f) as fichero :
                         f = fichero.read()
@@ -189,13 +188,16 @@ if os.name == 'posix':
                             # save the include directory with the db.h version
                             # (first occurrance only)
                             db_ver_inc_map[db_ver] = d
-                            if debug: print("db.h: found", db_ver, "in", d)
+                            if debug:
+                                print("db.h: found", db_ver, "in", d)
                         else:
                             # we already found a header for this library version
-                            if debug: print("db.h: ignoring", d)
+                            if debug:
+                                print("db.h: ignoring", d)
                     else:
                         # ignore this header, it didn't contain a version number
-                        if debug: print("db.h: unsupported version", db_ver, "in", d)
+                        if debug:
+                            print("db.h: unsupported version", db_ver, "in", d)
 
             db_found_vers = list(db_ver_inc_map.keys())
             db_found_vers.sort()
@@ -228,13 +230,15 @@ if os.name == 'posix':
                         db_libdir = os.path.abspath(os.path.dirname(dblib_file))
                         raise db_found
                     else:
-                        if debug: print("db lib: ", dblib, "not found")
+                        if debug:
+                            print("db lib: ", dblib, "not found")
         except db_found:
             print("Found Oracle Berkeley DB %d.%d installation." % db_ver)
             print("  include files in", db_incdir)
             print("  library files in", db_libdir)
             print("  library name is lib"+dblib)
-            if debug: print("db: lib dir", db_libdir, "inc dir", db_incdir)
+            if debug:
+                print("db: lib dir", db_libdir, "inc dir", db_incdir)
 
             incdir  = db_incdir
             libdir  = db_libdir
@@ -256,10 +260,11 @@ if os.name == 'posix':
         incdir = os.path.join(BERKELEYDB_DIR, 'include')
     if not libdir:
         libdir = os.path.join(BERKELEYDB_DIR, 'lib')
-    if not '-ldb' in LIBS:
+    if '-ldb' not in LIBS:
         libname = [dblib]
     else:
-        if debug: print("LIBS already contains '-ldb' not adding our own", "'-l"+dblib+"'")
+        if debug:
+            print("LIBS already contains '-ldb' not adding our own", "'-l"+dblib+"'")
         libname = []
     utils = []
 
