@@ -24,9 +24,6 @@ Options:
     version of python used to run test.py.  Highly recommended.  Tests will be
     run from the source directory.
 
--c
-    Use pychecker.
-
 -d
     Instead of the normal test harness, run a debug version which doesn't
     catch any exceptions.  This is occasionally handy when the unittest code
@@ -54,16 +51,6 @@ Options:
     Keep running the selected tests in a loop.  You may experience memory
     leakage, but this is a handy option for catching race conditions.
 
--u
--m
-    Use the PyUnit GUI instead of output to the command line.  The GUI imports
-    tests on its own, taking care to reload all dependencies on each run.  The
-    debug (-d), verbose (-v), and Loop (-L) options will be ignored.  The
-    testfilter filter is also not applied.
-
-    -m starts the gui minimized.  Double-clicking the progress bar will start
-    the import and run all tests.
-
 -p
     Show running progress.  It can be combined with -v or -vv.
 
@@ -108,14 +95,14 @@ Extreme (yet useful) examples:
     As before, but runs all tests whose names aren't precisely
     "checkWriteClient".  Useful to avoid a specific failing test you don't
     want to deal with just yet.
-
-    test.py -m . "!^checkWriteClient$"
-
-    As before, but now opens up a minimized PyUnit GUI window (only showing
-    the progress bar).  Useful for refactoring runs where you continually want
-    to make sure all tests still pass.
 """
 
+# XXX: The following "ruff" directive silences the warnings because the imports
+# are not at the beginning of the file, because we are changing the warning
+# level first.
+
+# ruff: noqa: E402
+
 import warnings
 # Simulate "python -Wdefault".
 # http://docs.python.org/dev/library/warnings.html#updating-code-for-new-versions-of-python
@@ -133,7 +120,6 @@ import getopt
 import unittest
 import linecache
 import traceback
-import pathlib
 
 from unittest import TextTestResult
 
@@ -180,8 +166,6 @@ class ImmediateTestResult(TextTestResult):
             self._maxWidth -= len('xxxx/xxxx (xxx.x%): ') + 1
 
     def stopTest(self, test):
-        import time
-        #print time.time()-self._time
         if gc.garbage:
             print(test)
             print(gc.garbage)
@@ -196,9 +180,6 @@ class ImmediateTestResult(TextTestResult):
         errlist.append((test, tb))
 
     def startTest(self, test):
-        import time
-        self._time=time.time()
-
         if self._progress:
             self.stream.write('\r%4d' % (self.testsRun + 1))
             if self._count:
@@ -331,18 +312,6 @@ def filter_testcases(s, rx):
     return new
 
 
-def gui_runner(files, test_filter):
-    sys.path.insert(0, os.path.join(os.getcwd(), 'utilities'))
-    import unittestgui
-    suites = []
-    for file in files:
-        suites.append(finder.module_from_path(file) + '.test_suite')
-
-    suites = ", ".join(suites)
-    minimal = (GUI == 'minimal')
-    unittestgui.main(suites, minimal)
-
-
 def runner(files, test_filter, debug):
     runner = ImmediateTestRunner(verbosity=VERBOSE, debug=debug,
                                  progress=progress)
@@ -385,9 +354,7 @@ def main(module_filter, test_filter):
     # Initialize the path and cwd
     pathinit = PathInit()
 
-    if GUI:
-        gui_runner(files, test_filter)
-    elif LOOP:
+    if LOOP:
         while True:
             r = runner(files, test_filter, debug)
     elif TRACE:
@@ -410,7 +377,6 @@ def process_args(argv=None):
     global test_filter
     global VERBOSE
     global LOOP
-    global GUI
     global TRACE
     global debug
     global debugger
@@ -425,7 +391,6 @@ def process_args(argv=None):
     test_filter = None
     VERBOSE = 0
     LOOP = False
-    GUI = 0
     TRACE = False
     # Don't collect test results; simply let tests crash
     debug = False
@@ -447,9 +412,6 @@ def process_args(argv=None):
     for k, v in opts:
         if k == '-b':
             build = True
-        elif k == '-c':
-            os.environ['PYCHECKER'] = "-q"
-            import pychecker.checker
         elif k == '-d':
             debug = True
         elif k == '-D':
@@ -467,10 +429,6 @@ def process_args(argv=None):
             sys.exit(0)
         elif k == '-L':
             LOOP = True
-        elif k == '-u':
-            GUI = 1
-        elif k == '-m':
-            GUI = 'minimal'
         elif k == '-p':
             progress = True
         elif k == '-T':
@@ -483,7 +441,6 @@ def process_args(argv=None):
         print('gc threshold:', gc.get_threshold())
 
     if gcflags:
-        import gc
         val = 0
         for flag in gcflags:
             v = getattr(gc, flag, None)
