@@ -1,53 +1,49 @@
-"""
-Copyright (c) 2008-2024, Jesús Cea Avión <jcea@jcea.es>
-All rights reserved.
-
-Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions
-are met:
-
-    1. Redistributions of source code must retain the above copyright
-    notice, this list of conditions and the following disclaimer.
-
-    2. Redistributions in binary form must reproduce the above
-    copyright notice, this list of conditions and the following
-    disclaimer in the documentation and/or other materials provided
-    with the distribution.
-
-    3. Neither the name of Jesús Cea Avión nor the names of its
-    contributors may be used to endorse or promote products derived
-    from this software without specific prior written permission.
-
-    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
-    CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
-    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
-    MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
-    BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
-            TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-            DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
-    ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
-    TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
-    THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-    SUCH DAMAGE.
-    """
+# Copyright (c) 2008-2024, Jesús Cea Avión <jcea@jcea.es>
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+#
+#     1. Redistributions of source code must retain the above copyright
+#     notice, this list of conditions and the following disclaimer.
+#
+#     2. Redistributions in binary form must reproduce the above
+#     copyright notice, this list of conditions and the following
+#     disclaimer in the documentation and/or other materials provided
+#     with the distribution.
+#
+#     3. Neither the name of Jesús Cea Avión nor the names of its
+#     contributors may be used to endorse or promote products derived
+#     from this software without specific prior written permission.
+#
+#     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
+#     CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
+#     INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+#     MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+#     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
+#     BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+#     EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+#     TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+#     DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+#     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
+#     TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
+#     THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+#     SUCH DAMAGE.
 
 """Run all test cases.
 """
 
 import sys
-import os, os.path
+import os
+import os.path
 import unittest
 import threading
 import platform
 import pathlib
 
 import berkeleydb
-from berkeleydb import db, dbutils, dbshelve, \
-        hashopen, btopen, rnopen, dbobj
-
-from test.support.socket_helper import find_unused_port
+from berkeleydb import db
 
 if sys.version_info >= (3, 10):
     from test.support.os_helper import rmtree, unlink
@@ -55,16 +51,6 @@ else:
     from test.support import rmtree, unlink
 
 
-verbose = 0
-if 'verbose' in sys.argv:
-    verbose = 1
-    sys.argv.remove('verbose')
-
-if 'silent' in sys.argv:  # take care of old flag, just in case
-    verbose = 0
-    sys.argv.remove('silent')
-
-
 def print_versions():
     print()
     print('-=' * 38)
@@ -77,7 +63,7 @@ def print_versions():
     # Workaround for allowing generating an EGGs as a ZIP files.
     suffix="__"
     print(f'py module:          {getattr(berkeleydb, "__file"+suffix)}')
-    print(f'extension module:   {getattr(berkeleydb._db, "__file"+suffix)}')
+    print(f'extension module:   {getattr(berkeleydb.db, "__file"+suffix)}')
     print(f'Test working dir:   {get_test_path_prefix()}')
     print('python version:     %s %s' % \
             (sys.version.replace("\r", "").replace("\n", ""), \
@@ -152,7 +138,7 @@ class pathTest(unittest.TestCase):
         path_dir = pathlib.Path(os.environ.get('BERKELEYDB_SO_PATH', None))
         self.assertIsNotNone(path_dir)
         path_dir = path_dir.resolve()
-        path_file = pathlib.Path(berkeleydb._db.__file__).resolve()
+        path_file = pathlib.Path(berkeleydb.db.__file__).resolve()
         self.assertTrue(path_file.is_relative_to(path_dir),
                         msg=f"Wrong library: '{path_file}' not in '{path_dir}'")
 
@@ -165,13 +151,14 @@ def suite(module_prefix='', timing_check=None):
         'test_db',
         'test_compare',
         'test_compat',
+        'test_concurrent_data_store',
         'test_cursor_pget_bug',
         'test_dbobj',
         'test_dbshelve',
         'test_dbtables',
         'test_distributed_transactions',
         'test_early_close',
-        'test_concurrent_data_store',
+        'test_encryption',
         'test_fileid',
         'test_get_none',
         'test_heap',
