@@ -1,49 +1,43 @@
-"""
-Copyright (c) 2008-2024, Jesús Cea Avión <jcea@jcea.es>
-All rights reserved.
-
-Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions
-are met:
-
-    1. Redistributions of source code must retain the above copyright
-    notice, this list of conditions and the following disclaimer.
-
-    2. Redistributions in binary form must reproduce the above
-    copyright notice, this list of conditions and the following
-    disclaimer in the documentation and/or other materials provided
-    with the distribution.
-
-    3. Neither the name of Jesús Cea Avión nor the names of its
-    contributors may be used to endorse or promote products derived
-    from this software without specific prior written permission.
-
-    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
-    CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
-    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
-    MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
-    BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
-            TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-            DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
-    ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
-    TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
-    THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-    SUCH DAMAGE.
-    """
+# Copyright (c) 2008-2024, Jesús Cea Avión <jcea@jcea.es>
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+#
+#     1. Redistributions of source code must retain the above copyright
+#     notice, this list of conditions and the following disclaimer.
+#
+#     2. Redistributions in binary form must reproduce the above
+#     copyright notice, this list of conditions and the following
+#     disclaimer in the documentation and/or other materials provided
+#     with the distribution.
+#
+#     3. Neither the name of Jesús Cea Avión nor the names of its
+#     contributors may be used to endorse or promote products derived
+#     from this software without specific prior written permission.
+#
+#     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
+#     CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
+#     INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+#     MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+#     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
+#     BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+#     EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+#     TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+#     DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+#     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
+#     TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
+#     THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+#     SUCH DAMAGE.
 
 """
 TestCases for DB.associate.
 """
 
-import sys, os, string
-import time
-from pprint import pprint
-
 import unittest
-from .test_all import db, dbshelve, rmtree, verbose, \
-        get_new_environment_path
+from berkeleydb import db, dbshelve
+from .test_all import rmtree, get_new_environment_path
 
 
 #----------------------------------------------------------------------
@@ -123,11 +117,6 @@ class AssociateErrorTestCase(unittest.TestCase):
         rmtree(self.homeDir)
 
     def test00_associateDBError(self):
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test00_associateDBError..." % \
-                  self.__class__.__name__)
-
         dupDB = db.DB(self.env)
         dupDB.set_flags(db.DB_DUP)
         dupDB.open(self.filename, "primary", db.DB_BTREE, db.DB_CREATE)
@@ -177,7 +166,7 @@ class AssociateTestCase(unittest.TestCase):
             if (db.version() >= (5, 3)) and (self.dbtype == db.DB_HEAP):
                 d.append(b'%02d|' % key + b'|'.join(value), txn=txn)
             else:
-                if type(self.keytype) == type(b''):
+                if isinstance(self.keytype, bytes):
                     key = b'%02d' % key
                 d.put(key, b'|'.join(value), txn=txn)
 
@@ -227,11 +216,6 @@ class AssociateTestCase(unittest.TestCase):
         self.finish_test(self.secDB)
 
     def test01_associateWithDB(self):
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test01_associateWithDB..." % \
-                  self.__class__.__name__)
-
         return self._associateWithDB(self.getGenre)
 
     def _associateAfterDB(self, getGenre) :
@@ -249,27 +233,12 @@ class AssociateTestCase(unittest.TestCase):
         self.finish_test(self.secDB)
 
     def test02_associateAfterDB(self):
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test02_associateAfterDB..." % \
-                  self.__class__.__name__)
-
         return self._associateAfterDB(self.getGenre)
 
     def test03_associateWithDB(self):
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test03_associateWithDB..." % \
-                  self.__class__.__name__)
-
         return self._associateWithDB(self.getGenreList)
 
     def test04_associateAfterDB(self):
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test04_associateAfterDB..." % \
-                  self.__class__.__name__)
-
         return self._associateAfterDB(self.getGenreList)
 
 
@@ -289,8 +258,6 @@ class AssociateTestCase(unittest.TestCase):
         vals[1].index(b'Unnamed')
         vals[1].index(b'unknown')
 
-        if verbose:
-            print("Primary key traversal:")
         self.cur = self.getDB().cursor(txn)
         count = 0
         rec = self.cur.first()
@@ -299,19 +266,15 @@ class AssociateTestCase(unittest.TestCase):
                 key = rec[1].split(b'|')[0]
             else:
                 key = rec[0]
-            if type(self.keytype) == type(b''):
+            if isinstance(self.keytype, bytes):
                 self.assertTrue(int(key))  # for primary db, key is a number
             else:
-                self.assertTrue(key and type(key) == type(0))
+                self.assertTrue(key and isinstance(key, int))
             count = count + 1
-            if verbose:
-                print(rec)
             rec = self.cur.next()
         self.assertEqual(count, len(musicdata))  # all items accounted for
 
 
-        if verbose:
-            print("Secondary key traversal:")
         self.cur = secDB.cursor(txn)
         count = 0
 
@@ -336,8 +299,6 @@ class AssociateTestCase(unittest.TestCase):
         self.assertEqual(rec[0], b'Jazz')
         while rec is not None:
             count = count + 1
-            if verbose:
-                print(rec)
             rec = self.cur.next()
         # all items accounted for EXCEPT for 1 with "Blues" genre
         self.assertEqual(count, len(musicdata)-1)
@@ -345,15 +306,12 @@ class AssociateTestCase(unittest.TestCase):
         self.cur = None
 
     def getGenre(self, priKey, priData):
-        self.assertEqual(type(priData), type(b''))
+        self.assertTrue(isinstance(priData, bytes))
         genre = 2
         if (db.version() >= (5, 3)) and (self.dbtype == db.DB_HEAP):
             genre = 3
         genre = priData.split(b'|')[genre]
 
-        if verbose:
-            print('getGenre key: %r data: %r' % (priKey, priData))
-
         if genre == b'Blues':
             return db.DB_DONOTINDEX
         else:
@@ -361,7 +319,7 @@ class AssociateTestCase(unittest.TestCase):
 
     def getGenreList(self, priKey, PriData) :
         v = self.getGenre(priKey, PriData)
-        if type(v) == type(b'') :
+        if isinstance(v, bytes) :
             v = [v]
         return v
 
@@ -402,11 +360,6 @@ class AssociateBTreeTxnTestCase(AssociateBTreeTestCase):
                 txn.commit()
 
     def test13_associate_in_transaction(self):
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test13_associateAutoCommit..." % \
-                  self.__class__.__name__)
-
         txn = self.env.txn_begin()
         try:
             self.createDB(txn=txn)
@@ -438,15 +391,13 @@ class ShelveAssociateTestCase(AssociateTestCase):
 
     def addDataToDB(self, d):
         for key, value in list(musicdata.items()):
-            if type(self.keytype) == type(b''):
+            if isinstance(self.keytype, bytes):
                 key = b'%02d' % key
             d.put(key, value)    # save the value as is this time
 
 
     def getGenre(self, priKey, priData):
-        self.assertEqual(type(priData), type(()))
-        if verbose:
-            print('getGenre key: %r data: %r' % (priKey, priData))
+        self.assertTrue(isinstance(priData, tuple))
         genre = priData[2]
         if genre == b'Blues':
             return db.DB_DONOTINDEX
@@ -483,7 +434,7 @@ class ThreadedAssociateTestCase(AssociateTestCase):
 
     def writer1(self, d):
         for key, value in list(musicdata.items()):
-            if type(self.keytype) == type(b''):
+            if isinstance(self.keytype, bytes):
                 key = b'%02d' % key
             d.put(key, b'|'.join(value))
 
