@@ -1,37 +1,35 @@
-"""
-Copyright (c) 2008-2024, Jesús Cea Avión <jcea@jcea.es>
-All rights reserved.
-
-Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions
-are met:
-
-    1. Redistributions of source code must retain the above copyright
-    notice, this list of conditions and the following disclaimer.
-
-    2. Redistributions in binary form must reproduce the above
-    copyright notice, this list of conditions and the following
-    disclaimer in the documentation and/or other materials provided
-    with the distribution.
-
-    3. Neither the name of Jesús Cea Avión nor the names of its
-    contributors may be used to endorse or promote products derived
-    from this software without specific prior written permission.
-
-    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
-    CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
-    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
-    MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
-    BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
-            TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-            DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
-    ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
-    TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
-    THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-    SUCH DAMAGE.
-    """
+# Copyright (c) 2008-2024, Jesús Cea Avión <jcea@jcea.es>
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+#
+#     1. Redistributions of source code must retain the above copyright
+#     notice, this list of conditions and the following disclaimer.
+#
+#     2. Redistributions in binary form must reproduce the above
+#     copyright notice, this list of conditions and the following
+#     disclaimer in the documentation and/or other materials provided
+#     with the distribution.
+#
+#     3. Neither the name of Jesús Cea Avión nor the names of its
+#     contributors may be used to endorse or promote products derived
+#     from this software without specific prior written permission.
+#
+#     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
+#     CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
+#     INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+#     MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+#     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
+#     BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+#     EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+#     TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+#     DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+#     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
+#     TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
+#     THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+#     SUCH DAMAGE.
 
 """
 Basic TestCases for BTree and hash DBs, with and without a DBEnv, with
@@ -39,15 +37,13 @@ various DB flags, etc.
 """
 
 import os
-import errno
-import string
-from pprint import pprint
 import unittest
 import time
 import sys
 import pathlib
 
-from .test_all import db, rmtree, verbose, get_new_environment_path, \
+from berkeleydb import db
+from .test_all import rmtree, get_new_environment_path, \
         get_new_database_path, printable_bytes
 
 DASH = b'-'
@@ -58,11 +54,6 @@ DASH = b'-'
 class VersionTestCase(unittest.TestCase):
     def test00_version(self):
         info = db.version()
-        if verbose:
-            print('\n', '-=' * 20)
-            print('berkeleydb.db.version(): %s' % (info, ))
-            print(db.DB_VERSION_STRING)
-            print('-=' * 20)
         self.assertEqual(info, (db.DB_VERSION_MAJOR, db.DB_VERSION_MINOR,
                         db.DB_VERSION_PATCH))
 
@@ -156,9 +147,7 @@ class BasicTestCase(unittest.TestCase):
         if _txn:
             _txn.commit()
 
-        num = len(d)
-        if verbose:
-            print("created %d records" % num)
+        self.assertEqual(len(d), self._numKeys)
 
 
     def makeData(self, key):
@@ -171,14 +160,8 @@ class BasicTestCase(unittest.TestCase):
     def test01_GetsAndPuts(self):
         d = self.d
 
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test01_GetsAndPuts..." % self.__class__.__name__)
-
         for key in [b'0001', b'0100', b'0400', b'0700', b'0999']:
             data = d.get(key)
-            if verbose:
-                print(data)
 
         self.assertEqual(d.get(b'0321'), b'0321-0321-0321-0321-0321')
 
@@ -191,7 +174,6 @@ class BasicTestCase(unittest.TestCase):
             d.delete(b'abcd')
         except db.DBNotFoundError as val:
             self.assertEqual(val.args[0], db.DB_NOTFOUND)
-            if verbose: print(val)
         else:
             self.fail("expected exception")
 
@@ -210,7 +192,6 @@ class BasicTestCase(unittest.TestCase):
             d.put(b'abcd', b'this should fail', flags=db.DB_NOOVERWRITE)
         except db.DBKeyExistError as val:
             self.assertEqual(val.args[0], db.DB_KEYEXIST)
-            if verbose: print(val)
         else:
             self.fail("expected exception")
 
@@ -238,8 +219,7 @@ class BasicTestCase(unittest.TestCase):
             self.assertEqual(d.get(b'abcd'), b'same key')
 
         rec = d.get_both(b'0555', b'0555-0555-0555-0555-0555')
-        if verbose:
-            print(rec)
+        self.assertEqual(rec, b'0555-0555-0555-0555-0555')
 
         self.assertEqual(d.get_both(b'0555', b'bad data'), None)
 
@@ -252,32 +232,21 @@ class BasicTestCase(unittest.TestCase):
         self.assertEqual(data, self)
 
         s = d.stat()
-        self.assertEqual(type(s), type({}))
-        if verbose:
-            print('d.stat() returned this dictionary:')
-            pprint(s)
-
+        self.assertTrue(isinstance(s, dict))
 
     #----------------------------------------
 
     def test02_DictionaryMethods(self):
         d = self.d
 
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test02_DictionaryMethods..." % \
-                  self.__class__.__name__)
-
         for key in [b'0002', b'0101', b'0401', b'0701', b'0998']:
             data = d[key]
             self.assertEqual(data, self.makeData(key))
-            if verbose:
-                print(data)
 
         self.assertEqual(len(d), self._numKeys)
         keys = list(d.keys())
         self.assertEqual(len(keys), self._numKeys)
-        self.assertEqual(type(keys), type([]))
+        self.assertTrue(isinstance(keys, list))
 
         d[b'new record'] = b'a new record'
         self.assertEqual(len(d), self._numKeys+1)
@@ -289,10 +258,6 @@ class BasicTestCase(unittest.TestCase):
         keys = list(d.keys())
         self.assertEqual(len(keys), self._numKeys+1)
 
-        if verbose:
-            print("the first 10 keys are:")
-            pprint(keys[:10])
-
         self.assertEqual(d[b'new record'], b'a replacement record')
 
 # We check also the positional parameter
@@ -302,22 +267,13 @@ class BasicTestCase(unittest.TestCase):
 
         items = list(d.items())
         self.assertEqual(len(items), self._numKeys+1)
-        self.assertEqual(type(items), type([]))
-        self.assertEqual(type(items[0]), type(()))
+        self.assertTrue(isinstance(items, list))
+        self.assertTrue(isinstance(items[0], tuple))
         self.assertEqual(len(items[0]), 2)
 
-        if verbose:
-            print("the first 10 items are:")
-            pprint(items[:10])
-
         values = list(d.values())
         self.assertEqual(len(values), self._numKeys+1)
-        self.assertEqual(type(values), type([]))
-
-        if verbose:
-            print("the first 10 values are:")
-            pprint(values[:10])
-
+        self.assertTrue(isinstance(values, list))
 
     #----------------------------------------
 
@@ -327,8 +283,6 @@ class BasicTestCase(unittest.TestCase):
         for key in [b'0002', b'0101', b'0401', b'0701', b'0998']:
             data = d[key]
             self.assertEqual(data, self.makeData(key))
-            if verbose:
-                print(data)
 
         self.assertTrue(hasattr(d, "__contains__"))
         self.assertTrue(b'0401' in d)
@@ -338,11 +292,6 @@ class BasicTestCase(unittest.TestCase):
     #----------------------------------------
 
     def test03_SimpleCursorStuff(self, get_raises_error=0, set_raises_error=0):
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test03_SimpleCursorStuff (get_error %s, set_error %s)..." % \
-                  (self.__class__.__name__, get_raises_error, set_raises_error))
-
         if self.env and self.dbopenflags & db.DB_AUTO_COMMIT:
             txn = self.env.txn_begin()
         else:
@@ -353,14 +302,11 @@ class BasicTestCase(unittest.TestCase):
         count = 0
         while rec is not None:
             count = count + 1
-            if verbose and count % 100 == 0:
-                print(rec)
             try:
                 rec = c.next()
             except db.DBNotFoundError as val:
                 if get_raises_error:
                     self.assertEqual(val.args[0], db.DB_NOTFOUND)
-                    if verbose: print(val)
                     rec = None
                 else:
                     self.fail("unexpected DBNotFoundError")
@@ -374,14 +320,11 @@ class BasicTestCase(unittest.TestCase):
         count = 0
         while rec is not None:
             count = count + 1
-            if verbose and count % 100 == 0:
-                print(rec)
             try:
                 rec = c.prev()
             except db.DBNotFoundError as val:
                 if get_raises_error:
                     self.assertEqual(val.args[0], db.DB_NOTFOUND)
-                    if verbose: print(val)
                     rec = None
                 else:
                     self.fail("unexpected DBNotFoundError")
@@ -404,7 +347,6 @@ class BasicTestCase(unittest.TestCase):
             n = c.set(b'bad key')
         except db.DBNotFoundError as val:
             self.assertEqual(val.args[0], db.DB_NOTFOUND)
-            if verbose: print(val)
         else:
             if set_raises_error:
                 self.fail("expected exception")
@@ -418,7 +360,6 @@ class BasicTestCase(unittest.TestCase):
             n = c.get_both(b'0404', b'bad data')
         except db.DBNotFoundError as val:
             self.assertEqual(val.args[0], db.DB_NOTFOUND)
-            if verbose: print(val)
         else:
             if get_raises_error:
                 self.fail("expected exception")
@@ -427,18 +368,13 @@ class BasicTestCase(unittest.TestCase):
 
         if self.d.get_type() == db.DB_BTREE:
             rec = c.set_range(b'011')
-            if verbose:
-                print("searched for b'011', found: ", rec)
-
             rec = c.set_range(b'011', dlen=0, doff=0)
-            if verbose:
-                print("searched (partial) for b'011', found: ", rec)
-            if rec[1] != b'': self.fail('expected empty data portion')
+            if rec[1] != b'':
+                self.fail('expected empty data portion')
 
             ev = c.set_range(b'empty value')
-            if verbose:
-                print("search for b'empty value' returned", ev)
-            if ev[1] != b'': self.fail('empty value lookup failed')
+            if ev[1] != b'':
+                self.fail('empty value lookup failed')
 
         c.set(b'0499')
         c.delete()
@@ -447,7 +383,6 @@ class BasicTestCase(unittest.TestCase):
         except db.DBKeyEmptyError as val:
             if get_raises_error:
                 self.assertEqual(val.args[0], db.DB_KEYEMPTY)
-                if verbose: print(val)
             else:
                 self.fail("unexpected DBKeyEmptyError")
         else:
@@ -485,14 +420,10 @@ class BasicTestCase(unittest.TestCase):
         }
         for method, args in list(methods_to_test.items()):
             try:
-                if verbose:
-                    print("attempting to use a closed cursor's %s method" % \
-                          method)
                 # a bug may cause a NULL pointer dereference...
                 getattr(c, method)(*args)
             except db.DBError as val:
                 self.assertEqual(val.args[0], 0)
-                if verbose: print(val)
             else:
                 self.fail("no exception raised when using a buggy cursor's"
                           "%s method" % method)
@@ -510,33 +441,18 @@ class BasicTestCase(unittest.TestCase):
 
     def test03b_SimpleCursorWithoutGetReturnsNone0(self):
         # same test but raise exceptions instead of returning None
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test03b_SimpleCursorStuffWithoutGetReturnsNone..." % \
-                  self.__class__.__name__)
-
         old = self.d.set_get_returns_none(0)
         self.assertEqual(old, 2)
         self.test03_SimpleCursorStuff(get_raises_error=1, set_raises_error=1)
 
     def test03b_SimpleCursorWithGetReturnsNone1(self):
         # same test but raise exceptions instead of returning None
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test03b_SimpleCursorStuffWithoutGetReturnsNone..." % \
-                  self.__class__.__name__)
-
         old = self.d.set_get_returns_none(1)
+        self.assertEqual(old, 2)
         self.test03_SimpleCursorStuff(get_raises_error=0, set_raises_error=1)
 
-
     def test03c_SimpleCursorGetReturnsNone2(self):
         # same test but raise exceptions instead of returning None
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test03c_SimpleCursorStuffWithoutSetReturnsNone..." % \
-                  self.__class__.__name__)
-
         old = self.d.set_get_returns_none(1)
         self.assertEqual(old, 2)
         old = self.d.set_get_returns_none(2)
@@ -555,11 +471,6 @@ class BasicTestCase(unittest.TestCase):
 
     def test04_PartialGetAndPut(self):
         d = self.d
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test04_PartialGetAndPut..." % \
-                  self.__class__.__name__)
-
         key = b'partialTest'
         data = b'1' * 1000 + b'2' * 1000
         d.put(key, data)
@@ -586,10 +497,6 @@ class BasicTestCase(unittest.TestCase):
 
     def test05_GetSize(self):
         d = self.d
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test05_GetSize..." % self.__class__.__name__)
-
         for i in range(1, 50000, 500):
             key = b'size%d' % i
             d.put(key, b'1' * i)
@@ -599,11 +506,7 @@ class BasicTestCase(unittest.TestCase):
 
     def test06_Truncate(self):
         d = self.d
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test06_Truncate..." % self.__class__.__name__)
-
-        d.put(b'abcde', b'ABCDE');
+        d.put(b'abcde', b'ABCDE')
         num = d.truncate()
         self.assertTrue(num >= 1, "truncate returned <= 0 on non-empty database")
         num = d.truncate()
@@ -714,9 +617,9 @@ class BasicTestCase(unittest.TestCase):
 
     def test08_exists(self) :
         self.d.put(b'abcde', b'ABCDE')
-        self.assertTrue(self.d.exists(b'abcde') == True,
+        self.assertTrue(self.d.exists(b'abcde'),
                 "DB->exists() returns wrong value")
-        self.assertTrue(self.d.exists(b'x') == False,
+        self.assertFalse(self.d.exists(b'x'),
                 "DB->exists() returns wrong value")
 
     #----------------------------------------
@@ -730,10 +633,10 @@ class BasicTestCase(unittest.TestCase):
         ret = d.compact(flags=db.DB_FREELIST_ONLY)
         self.assertEqual(0, ret['pages_truncated'])
         self.assertEqual(keys, set(ret.keys()))
-        d.put(b'abcde', b'ABCDE');
-        d.put(b'bcde', b'BCDE');
-        d.put(b'abc', b'ABC');
-        d.put(b'monty', b'python');
+        d.put(b'abcde', b'ABCDE')
+        d.put(b'bcde', b'BCDE')
+        d.put(b'abc', b'ABC')
+        d.put(b'monty', b'python')
         d.delete(b'abc')
         d.delete(b'bcde')
         d.compact(start=b'abcde', stop=b'monty', txn=None,
@@ -812,10 +715,6 @@ class BasicWithEnvTestCase(BasicTestCase):
         if not self.env:
             return
 
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test09_EnvRemoveAndRename..." % self.__class__.__name__)
-
         # can't rename or remove an open DB
         self.d.close()
 
@@ -827,10 +726,6 @@ class BasicWithEnvTestCase(BasicTestCase):
         if not self.env:
             return
 
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test09_EnvRemoveAndRename..." % self.__class__.__name__)
-
         # can't rename or remove an open DB
         self.d.close()
 
@@ -873,10 +768,6 @@ class BasicTransactionTestCase(BasicTestCase):
 
     def test06_Transactions(self):
         d = self.d
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test06_Transactions..." % self.__class__.__name__)
-
         self.assertEqual(d.get(b'new rec', txn=self.txn), None)
         d.put(b'new rec', b'this is a new record', self.txn)
         self.assertEqual(d.get(b'new rec', txn=self.txn),
@@ -899,8 +790,6 @@ class BasicTransactionTestCase(BasicTestCase):
         count = 0
         while rec is not None:
             count = count + 1
-            if verbose and count % 100 == 0:
-                print(rec)
             rec = c.next()
         self.assertEqual(count, self._numKeys+1)
 
@@ -910,7 +799,7 @@ class BasicTransactionTestCase(BasicTestCase):
         # flush pending updates
         self.env.txn_checkpoint (0, 0, 0)
 
-        statDict = self.env.log_stat(0);
+        statDict = self.env.log_stat(0)
         self.assertIn('magic', statDict)
         self.assertIn('version', statDict)
         self.assertIn('cur_file', statDict)
@@ -920,9 +809,6 @@ class BasicTransactionTestCase(BasicTestCase):
         logs = self.env.log_archive(db.DB_ARCH_ABS | db.DB_ARCH_LOG)
         self.assertEqual(logs[0][-14:], 'log.0000000001')
         self.assertNotEqual(logs, None)
-        for log in logs:
-            if verbose:
-                print('log file: ' + log)
         logs = self.env.log_archive(db.DB_ARCH_REMOVE)
         self.assertTrue(not logs)
 
@@ -935,9 +821,9 @@ class BasicTransactionTestCase(BasicTestCase):
         self.d.put(b'abcde', b'ABCDE', txn=txn)
         txn.commit()
         txn = self.env.txn_begin()
-        self.assertTrue(self.d.exists(b'abcde', txn=txn) == True,
+        self.assertTrue(self.d.exists(b'abcde', txn=txn),
                 "DB->exists() returns wrong value")
-        self.assertTrue(self.d.exists(b'x', txn=txn) == False,
+        self.assertFalse(self.d.exists(b'x', txn=txn),
                 "DB->exists() returns wrong value")
         txn.abort()
 
@@ -945,11 +831,7 @@ class BasicTransactionTestCase(BasicTestCase):
 
     def test09_TxnTruncate(self):
         d = self.d
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test09_TxnTruncate..." % self.__class__.__name__)
-
-        d.put(b'abcde', b'ABCDE');
+        d.put(b'abcde', b'ABCDE')
         txn = self.env.txn_begin()
         num = d.truncate(txn)
         self.assertTrue(num >= 1, "truncate returned <= 0 on non-empty database")
@@ -965,7 +847,7 @@ class BasicTransactionTestCase(BasicTestCase):
         txn.abort()
         try:
             txn.abort()
-        except db.DBError as e:
+        except db.DBError:
             pass
         else:
             raise RuntimeError("DBTxn.abort() called after DB_TXN no longer valid w/o an exception")
@@ -974,7 +856,7 @@ class BasicTransactionTestCase(BasicTestCase):
         txn.commit()
         try:
             txn.commit()
-        except db.DBError as e:
+        except db.DBError:
             pass
         else:
             raise RuntimeError("DBTxn.commit() called after DB_TXN no longer valid w/o an exception")
@@ -1097,22 +979,14 @@ class BTreeRecnoTestCase(BasicTestCase):
 
     def test09_RecnoInBTree(self):
         d = self.d
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test09_RecnoInBTree..." % self.__class__.__name__)
-
         rec = d.get(200)
-        self.assertEqual(type(rec), type(()))
+        self.assertTrue(isinstance(rec, tuple))
         self.assertEqual(len(rec), 2)
-        if verbose:
-            print("Record #200 is ", rec)
 
         c = d.cursor()
         c.set(b'0200')
         num = c.get_recno()
-        self.assertEqual(type(num), type(1))
-        if verbose:
-            print("recno of d[b'0200'] is ", num)
+        self.assertTrue(isinstance(num, int))
 
         rec = c.current()
         self.assertEqual(c.set_recno(num), rec)
@@ -1131,11 +1005,6 @@ class BasicDUPTestCase(BasicTestCase):
 
     def test10_DuplicateKeys(self):
         d = self.d
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test10_DuplicateKeys..." % \
-                  self.__class__.__name__)
-
         d.put(b'dup0', b'before')
         for x in b'The quick brown fox jumped over the lazy dog.'.split():
             d.put(b'dup1', x)
@@ -1143,8 +1012,6 @@ class BasicDUPTestCase(BasicTestCase):
 
         data = d.get(b'dup1')
         self.assertEqual(data, b'The')
-        if verbose:
-            print(data)
 
         c = d.cursor()
         rec = c.set(b'dup1')
@@ -1162,15 +1029,11 @@ class BasicDUPTestCase(BasicTestCase):
 
         rec = c.set(b'dup1')
         while rec is not None:
-            if verbose:
-                print(rec)
             rec = c.next_dup()
 
         c.set(b'dup1')
         rec = c.next_nodup()
         self.assertNotEqual(rec[0], b'dup1')
-        if verbose:
-            print(rec)
 
         c.close()
 
@@ -1204,10 +1067,6 @@ class BasicMultiDBTestCase(BasicTestCase):
 
     def test11_MultiDB(self):
         d1 = self.d
-        if verbose:
-            print('\n', '-=' * 30)
-            print("Running %s.test11_MultiDB..." % self.__class__.__name__)
-
         d2 = db.DB(self.env)
         d2.open(self.filename, "second", self.dbtype,
                 self.dbopenflags|db.DB_CREATE)
@@ -1245,8 +1104,6 @@ class BasicMultiDBTestCase(BasicTestCase):
         rec = c1.first()
         while rec is not None:
             count = count + 1
-            if verbose and (count % 50) == 0:
-                print(rec)
             rec = c1.next()
         self.assertEqual(count, self._numKeys)
 
@@ -1254,8 +1111,6 @@ class BasicMultiDBTestCase(BasicTestCase):
         rec = c2.first()
         while rec is not None:
             count = count + 1
-            if verbose:
-                print(rec)
             rec = c2.next()
         self.assertEqual(count, 9)
 
@@ -1263,8 +1118,6 @@ class BasicMultiDBTestCase(BasicTestCase):
         rec = c3.first()
         while rec is not None:
             count = count + 1
-            if verbose:
-                print(rec)
             rec = c3.next()
         self.assertEqual(count, len(printable_bytes))
 
