@@ -1,50 +1,48 @@
-"""
-Copyright (c) 2008-2024, Jesús Cea Avión <jcea@jcea.es>
-All rights reserved.
-
-Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions
-are met:
-
-    1. Redistributions of source code must retain the above copyright
-    notice, this list of conditions and the following disclaimer.
-
-    2. Redistributions in binary form must reproduce the above
-    copyright notice, this list of conditions and the following
-    disclaimer in the documentation and/or other materials provided
-    with the distribution.
-
-    3. Neither the name of Jesús Cea Avión nor the names of its
-    contributors may be used to endorse or promote products derived
-    from this software without specific prior written permission.
-
-    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
-    CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
-    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
-    MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
-    BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
-            TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-            DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
-    ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
-    TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
-    THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-    SUCH DAMAGE.
-    """
+# Copyright (c) 2008-2024, Jesús Cea Avión <jcea@jcea.es>
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+#
+#     1. Redistributions of source code must retain the above copyright
+#     notice, this list of conditions and the following disclaimer.
+#
+#     2. Redistributions in binary form must reproduce the above
+#     copyright notice, this list of conditions and the following
+#     disclaimer in the documentation and/or other materials provided
+#     with the distribution.
+#
+#     3. Neither the name of Jesús Cea Avión nor the names of its
+#     contributors may be used to endorse or promote products derived
+#     from this software without specific prior written permission.
+#
+#     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
+#     CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
+#     INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+#     MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+#     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
+#     BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+#     EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+#     TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+#     DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+#     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
+#     TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
+#     THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+#     SUCH DAMAGE.
 
 """TestCases for distributed transactions.
 """
 
-import os, os.path
+import os
+import os.path
 import time
 import queue
 import unittest
-import sys
-
-from .test_all import db, rmtree, find_unused_port, verbose, \
-        get_new_environment_path, get_new_database_path
+from test.support.socket_helper import find_unused_port
 
+from berkeleydb import db
+from .test_all import rmtree, get_new_environment_path
 
 #----------------------------------------------------------------------
 
@@ -194,8 +192,8 @@ class DBReplicationManager(DBReplication) :
         self.dbenvMaster.repmgr_set_ack_policy(db.DB_REPMGR_ACKS_ALL)
         self.dbenvClient.repmgr_set_ack_policy(db.DB_REPMGR_ACKS_ALL)
 
-        self.dbenvMaster.repmgr_start(1, db.DB_REP_MASTER);
-        self.dbenvClient.repmgr_start(1, db.DB_REP_CLIENT);
+        self.dbenvMaster.repmgr_start(1, db.DB_REP_MASTER)
+        self.dbenvClient.repmgr_start(1, db.DB_REP_CLIENT)
 
         self.assertEqual(self.dbenvMaster.rep_get_nsites(),2)
         self.assertEqual(self.dbenvClient.rep_get_nsites(),2)
@@ -230,7 +228,7 @@ class DBReplicationManager(DBReplication) :
         self.assertTrue((d[2]==db.DB_REPMGR_CONNECTED) or \
                 (d[2]==db.DB_REPMGR_DISCONNECTED))
 
-        d = self.dbenvMaster.repmgr_stat(flags=db.DB_STAT_CLEAR);
+        d = self.dbenvMaster.repmgr_stat(flags=db.DB_STAT_CLEAR)
         self.assertTrue("msgs_queued" in d)
 
         self.dbMaster=db.DB(self.dbenvMaster)
@@ -379,7 +377,8 @@ class DBBaseReplication(DBReplication) :
         def thread_do(env, q, envid, election_status, must_be_master) :
             while True :
                 v=q.get()
-                if v is None : return
+                if v is None:
+                    return
                 env.rep_process_message(v[0], v[1], envid)
 
         self.thread_do = thread_do
@@ -424,7 +423,7 @@ class DBBaseReplication(DBReplication) :
             txn.commit()
             break
 
-        d = self.dbenvMaster.rep_stat(flags=db.DB_STAT_CLEAR);
+        d = self.dbenvMaster.rep_stat(flags=db.DB_STAT_CLEAR)
         self.assertTrue("master_changes" in d)
 
         txn=self.dbenvMaster.txn_begin()
@@ -470,7 +469,8 @@ class DBBaseReplication(DBReplication) :
         def thread_do(env, q, envid, election_status, must_be_master) :
             while True :
                 v=q.get()
-                if v is None : return
+                if v is None:
+                    return
                 r = env.rep_process_message(v[0],v[1],envid)
                 if must_be_master and self.confirmed_master :
                     self.dbenvMaster.rep_start(flags = db.DB_REP_MASTER)
